[![Build Status](https://travis-ci.com/majamassarini/automate-ws.svg?branch=main)](https://travis-ci.com/majamassarini/automate-ws)
[![codecov](https://codecov.io/gh/majamassarini/automate-ws/branch/main/graph/badge.svg?token=tPHRNf4csz)](https://codecov.io/gh/majamassarini/automate-ws)

## automate-home web server

The simplest user interface I was able to develop for the [automate-home project](https://github.com/majamassarini/automate-home).
